@@ -1,6 +1,7 @@
 #include <stddef.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include "dice_logic.h"
 #include "shared_header.h"
 #include "safe_functions.h"
 #include "yacc_header.h"
@@ -12,7 +13,7 @@ int random_fn_run_count = 0;
 int global_mock_value = 0;
 int secondary_mock_value = 0;
 MOCK_METHOD global_mock_style = NO_MOCK;
-extern unsigned int gnoll_errno;
+extern int gnoll_errno;
 
 void reset_mocking(){
     random_fn_run_count = 0;
@@ -82,8 +83,8 @@ int random_fn(int small, int big){
 // TODO: have min and max range rather than sides and start_offset
 
 int * perform_roll(
-    int number_of_dice,
-    int die_sides,
+    unsigned int number_of_dice,
+    unsigned int die_sides,
     EXPLOSION_TYPE explode,
     int start_value
 )
@@ -99,14 +100,14 @@ int * perform_roll(
     int single_die_roll = 0;
     int exploded_result = 0;
 
-    for(int i = 0; i < number_of_dice; i++){
+    for(unsigned int i = 0; i < number_of_dice; i++){
         all_dice_roll[i] = 0;
     }
 
     do{
-        for(int i = 0; i < number_of_dice; i++){
+        for(unsigned int i = 0; i < number_of_dice; i++){
             // TODO: Don't hardcode 1
-            int end_value = start_value+die_sides-1;
+            int end_value = (int)start_value+(int)die_sides-1;
             if (die_sides == 0){
                 start_value = end_value = 0;
             }
@@ -118,13 +119,13 @@ int * perform_roll(
             exploded_result += single_die_roll;
         }
 
-        explosion_condition_score += number_of_dice*die_sides;
+        explosion_condition_score += (int)number_of_dice*(int)die_sides;
         if (explode == ONLY_ONCE_EXPLOSION && explosion_count > 0){
             break;
         }
         if (explode == PENETRATING_EXPLOSION){
             die_sides--;
-            if (die_sides <= 0){ break; }
+            if (die_sides == 0){ break; }
         }
         explosion_count++;
     }while(explode && (exploded_result == explosion_condition_score) && explosion_count < EXPLOSION_LIMIT);
@@ -144,15 +145,3 @@ int * do_roll(roll_params rp){
         rp.start_value
     );
 }
-
-int validate_roll(int number_of_dice, int die_side)
-{
-    if (die_side < 0){
-        printf("Cannot roll a dice with a negative amount of sides\n");
-        gnoll_errno = INTERNAL_ASSERT;
-    }if (number_of_dice < 0){
-        printf("Cannot roll a negative number of dice\n");
-        gnoll_errno = INTERNAL_ASSERT;
-    }
-    return 0;
-}
